# E3SMCompareView

[![Test](https://github.com/ayenpure/QuickView/actions/workflows/test.yml/badge.svg)](https://github.com/ayenpure/QuickView/actions/workflows/test.yml)
[![Package and Release](https://github.com/ayenpure/QuickView/actions/workflows/package-and-release.yml/badge.svg)](https://github.com/ayenpure/QuickView/actions/workflows/package-and-release.yml)

**EAM QuickView** is an open-source, interactive visualization tool
designed for scientists working with the atmospheric component of the 
[Energy Exascale Earth System Model (E3SM)](https://e3sm.org/), 
known as the E3SM Atmosphere Model (EAM). 
Its Python- and [Trame](https://www.kitware.com/trame/)-based 
Graphical User Interface (GUI) provides
intuitive access to [ParaView](https://www.paraview.org/)'s 
powerful analysis and visualization capabilities, without the steep learning curve.

![Application](https://raw.githubusercontent.com/Kitware/QuickView/master/QuickView-app.png)

## Key Features

- Intuitive, minimalist interface tailored for atmospheric modeling.
- Multi-variable visualization with drag-and-drop layout.
- Persistent sessions - pick up where you left off.
- Support for EAM v2, v3, and upcoming v4 output formats.

## Quick Start

- Install and launch the app for [end users](docs/setup/for_end_users.md)
  or [app developers](docs/setup/for_app_developers.md).
- Download connectivity files of EAM's cubed-sphere grids from
  [Zenodo](https://doi.org/10.5281/zenodo.16908566).
- Optional: download [sample simulation output](https://zenodo.org/records/16922607)
  to test the app.
- For EAMv2 and v3 developers and users: if your simulation data files
  are *not* the original files written out by the model,
  i.e., if your files were generated by NCO, CDO, etc.
  check QuickView's [data format requirements](docs/userguide/data_requirements.md).
- For EAMxx developers and users: EAMxx's most recent output format
  changes might not have been accommodated. If your run into problems
  opening your data files, please check the
  [Issues tab on GitHub](https://github.com/ayenpure/QuickView/issues) and
  open a new issue if needed.

More detailed descriptions of how to download, install, and use QuickView
can be found in the [documentation](https://quickview.readthedocs.io/en/latest/).

## Project Background

QuickView is developed by [Kitware, Inc.](https://www.kitware.com/) in
collaboration with
[Pacific Northwest National Laboratory](https://www.pnnl.gov/), supported by the
U.S. Department of Energy's
[ASCR](https://www.energy.gov/science/ascr/advanced-scientific-computing-research)
and
[BER](https://www.energy.gov/science/ber/biological-and-environmental-research)
programs via [SciDAC](https://www.scidac.gov/).

### Contributors

- **Lead Developer**: Abhishek Yenpure (Kitware, Inc.)
- **Key Contributors**: Berk Geveci, Sebastien Jourdain (Kitware, Inc.); Hui
  Wan, Kai Zhang (PNNL)

## License

Apache Software License - see [LICENSE](LICENSE) file for details.
